# coding: utf-8

# flake8: noqa

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from montelo.client.api.datapoint_api import DatapointApi
from montelo.client.api.datapoint_run_api import DatapointRunApi
from montelo.client.api.dataset_api import DatasetApi
from montelo.client.api.experiment_api import ExperimentApi
from montelo.client.api.health_api import HealthApi
from montelo.client.api.logs_api import LogsApi

# import ApiClient
from montelo.client.api_response import ApiResponse
from montelo.client.api_client import ApiClient
from montelo.client.configuration import Configuration
from montelo.client.exceptions import OpenApiException
from montelo.client.exceptions import ApiTypeError
from montelo.client.exceptions import ApiValueError
from montelo.client.exceptions import ApiKeyError
from montelo.client.exceptions import ApiAttributeError
from montelo.client.exceptions import ApiException

# import models into sdk package
from montelo.client.models.add_to_dataset_input import AddToDatasetInput
from montelo.client.models.batch_add_to_dataset_input import BatchAddToDatasetInput
from montelo.client.models.create_datapoint_run_input import CreateDatapointRunInput
from montelo.client.models.create_dataset_input import CreateDatasetInput
from montelo.client.models.create_experiment_input import CreateExperimentInput
from montelo.client.models.create_log_input import CreateLogInput
from montelo.client.models.datapoint_dto import DatapointDto
from montelo.client.models.datapoint_run_dto import DatapointRunDto
from montelo.client.models.dataset_dto import DatasetDto
from montelo.client.models.delete_success_dto import DeleteSuccessDto
from montelo.client.models.end_log_input import EndLogInput
from montelo.client.models.event_queued_dto import EventQueuedDto
from montelo.client.models.experiment_dto import ExperimentDto
from montelo.client.models.experiment_with_datapoints_dto import ExperimentWithDatapointsDto
from montelo.client.models.full_dataset_dto import FullDatasetDto
from montelo.client.models.full_dataset_with_count_dto import FullDatasetWithCountDto
from montelo.client.models.health_controller_check200_response import HealthControllerCheck200Response
from montelo.client.models.health_controller_check200_response_info_value import HealthControllerCheck200ResponseInfoValue
from montelo.client.models.health_controller_check503_response import HealthControllerCheck503Response
from montelo.client.models.log_input import LogInput
from montelo.client.models.paginated_experiment_with_datapoints_dto import PaginatedExperimentWithDatapointsDto
from montelo.client.models.token_info import TokenInfo
from montelo.client.models.trace_input import TraceInput
from montelo.client.models.update_datapoint_run_input import UpdateDatapointRunInput



import os
from typing import Optional, List

from pydantic import StrictStr

from montelo.client import ApiClient, Configuration, CreateDatasetInput, DatasetDto, AddToDatasetInput, DatapointDto, \
    DatasetApi, DatapointApi, BatchAddToDatasetInput, CreateExperimentInput, ExperimentDto, ExperimentApi, \
    CreateDatapointRunInput, DatapointRunDto, DatapointRunApi, UpdateDatapointRunInput, EventQueuedDto, \
    PaginatedExperimentWithDatapointsDto, LogsApi, EndLogInput, CreateLogInput, LogInput
from montelo.context_vars import ctx_datapoint_run_id
from montelo.types import MonteloClientOptions


class MonteloClient:
    def __init__(self, options: Optional[MonteloClientOptions]):
        self.trace = None
        if options is None:
            api_key = os.getenv("MONTELO_API_KEY")
            base_url = os.getenv("MONTELO_BASE_URL", "https://api-sdk.montelo.ai")
        else:
            api_key = options.api_key or os.getenv("MONTELO_API_KEY")
            base_url = options.base_url or os.getenv("MONTELO_BASE_URL", "https://api-sdk.montelo.ai")

        if not api_key:
            raise Exception("Montelo API key not set.")

        self.configuration = Configuration(
            host=base_url,
            access_token=api_key
        )

    def set_trace(self, trace):
        self.trace = trace

    def get_trace(self):
        return self.trace

    def create_log(
            self,
            *,
            log: LogInput,
    ):
        token = ctx_datapoint_run_id.get()
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = LogsApi(api_client)
            api_instance.logs_controller_create_log(
                create_log_input=CreateLogInput(
                    datapoint_run_id=token,
                    log=log,
                    trace=self.trace,
                )
            )

    def end_log(
            self,
            *,
            id: StrictStr,
            log: EndLogInput
    ):
        token = ctx_datapoint_run_id.get()
        if not token:
            with ApiClient(configuration=self.configuration) as api_client:
                api_instance = LogsApi(api_client)
                api_instance.logs_controller_end_log(
                    log_id=id,
                    end_log_input=log,
                )

    def create_dataset(self, create_dataset_input: CreateDatasetInput) -> DatasetDto:
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = DatasetApi(api_client)
            return api_instance.dataset_controller_create(create_dataset_input=create_dataset_input)

    def create_datapoint(
            self,
            *,
            dataset_slug: StrictStr,
            add_to_dataset_input: AddToDatasetInput
    ) -> DatapointDto:
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = DatapointApi(api_client)
            return api_instance.datapoint_controller_add_to_dataset_by_slug(
                dataset_slug=dataset_slug,
                add_to_dataset_input=add_to_dataset_input,
            )

    def create_batch_datapoints(self, *, slug: StrictStr, datapoints: List[AddToDatasetInput]) -> None:
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = DatapointApi(api_client)
            batch_params = BatchAddToDatasetInput(datapoints=datapoints)
            api_instance.datapoint_controller_batch_add_to_dataset_by_slug(
                dataset_slug=slug,
                batch_add_to_dataset_input=batch_params
            )

    def create_experiment(
            self,
            *,
            slug: StrictStr,
            create_experiment_input: CreateExperimentInput
    ) -> ExperimentDto:
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = ExperimentApi(api_client)
            return api_instance.experiment_controller_create(
                dataset_slug=slug,
                create_experiment_input=create_experiment_input
            )

    def create_datapoint_run(self, create_datapoint_run_input: CreateDatapointRunInput) -> DatapointRunDto:
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = DatapointRunApi(api_client)
            return api_instance.datapoint_run_controller_create_datapoint_run(
                create_datapoint_run_input=create_datapoint_run_input
            )

    def update_datapoint_run(self, update_datapoint_run_input: UpdateDatapointRunInput) -> EventQueuedDto:
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = DatapointRunApi(api_client)
            return api_instance.datapoint_run_controller_update_datapoint_run(
                update_datapoint_run_input=update_datapoint_run_input
            )

    def get_datapoints_by_experiment_id(
            self,
            *,
            experiment_id: StrictStr,
            take: Optional[int] = None,
            skip: Optional[int] = None
    ) -> PaginatedExperimentWithDatapointsDto:
        with ApiClient(configuration=self.configuration) as api_client:
            api_instance = ExperimentApi(api_client)
            take_str = str(take) if take is not None else None
            skip_str = str(skip) if skip is not None else None

            return api_instance.experiment_controller_get_paginated_datapoints_for_experiment(
                experiment_id=experiment_id,
                take=take_str,
                skip=skip_str,
            )



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.api.datapoint_api import DatapointApi


class TestDatapointApi(unittest.TestCase):
    """DatapointApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DatapointApi()

    def tearDown(self) -> None:
        pass

    def test_datapoint_controller_add_to_dataset_by_slug(self) -> None:
        """Test case for datapoint_controller_add_to_dataset_by_slug

        """
        pass

    def test_datapoint_controller_batch_add_to_dataset_by_slug(self) -> None:
        """Test case for datapoint_controller_batch_add_to_dataset_by_slug

        """
        pass


if __name__ == '__main__':
    unittest.main()



from datetime import datetime
from typing import Callable

from cuid2 import cuid_wrapper

cuid_generator: Callable[[], str] = cuid_wrapper()


def format_utc_date(d: datetime):
    return d.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + 'Z'


def get_current_utc_time():
    # Get the current time in UTC
    now_utc = datetime.now()
    # Return the formatted string
    return format_utc_date(now_utc)



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AddToDatasetInput(BaseModel):
    """
    AddToDatasetInput
    """ # noqa: E501
    input: Dict[str, Any]
    expected_output: Dict[str, Any] = Field(alias="expectedOutput")
    source: StrictStr
    source_id: Optional[StrictStr] = Field(alias="sourceId")
    split: Optional[StrictStr] = None
    metadata: Optional[Dict[str, Any]] = None
    __properties: ClassVar[List[str]] = ["input", "expectedOutput", "source", "sourceId", "split", "metadata"]

    @field_validator('source')
    def source_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['TRACE', 'LOG', 'API']):
            raise ValueError("must be one of enum values ('TRACE', 'LOG', 'API')")
        return value

    @field_validator('split')
    def split_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['TRAIN', 'TEST']):
            raise ValueError("must be one of enum values ('TRAIN', 'TEST')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AddToDatasetInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if source_id (nullable) is None
        # and model_fields_set contains the field
        if self.source_id is None and "source_id" in self.model_fields_set:
            _dict['sourceId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AddToDatasetInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "input": obj.get("input"),
            "expectedOutput": obj.get("expectedOutput"),
            "source": obj.get("source"),
            "sourceId": obj.get("sourceId"),
            "split": obj.get("split"),
            "metadata": obj.get("metadata")
        })
        return _obj





import threading
from typing import Optional, Callable, Dict

from pydantic import StrictStr

from montelo.MonteloClient import MonteloClient
from montelo.client import CreateExperimentInput, ExperimentDto, CreateDatapointRunInput, UpdateDatapointRunInput
from montelo.context_vars import ctx_datapoint_run_id


class MonteloExperiments:
    def __init__(self, montelo_client: MonteloClient):
        self._montelo_client = montelo_client

    def create(
            self,
            *,
            dataset: StrictStr,
            name: StrictStr,
            description: Optional[StrictStr] = None
    ) -> ExperimentDto:
        params = CreateExperimentInput(
            name=name,
            description=description,
        )
        return self._montelo_client.create_experiment(
            slug=dataset,
            create_experiment_input=params,
        )

    def run(
            self,
            *,
            experiment_id: StrictStr,
            runner: Callable,
            evaluator: Callable,
            options: Optional[Dict] = None,
    ):
        try:
            # Default options
            take = 100
            skip = 0
            has_more_datapoints = True
            only_test_split = options.get("only_test_split", False) if options else False
            parallelism = options.get("parallelism", 1) if options else 1
            parallelism = 100 if parallelism > 100 else parallelism

            while has_more_datapoints:
                response = self._montelo_client.get_datapoints_by_experiment_id(
                    experiment_id=experiment_id,
                    take=take,
                    skip=skip
                )

                total_datapoints = response.total_datapoints
                datapoints = response.experiment.dataset.datapoints

                filtered_datapoints = [d for d in datapoints if not only_test_split or d.split == "TEST"]

                def process_datapoint(datapoint):
                    datapoint_run = self._montelo_client.create_datapoint_run(
                        create_datapoint_run_input=CreateDatapointRunInput(
                            experiment_id=experiment_id,
                            datapoint_id=datapoint.id,
                        )
                    )
                    ctx_datapoint_run_id.set(datapoint_run.id)

                    output = runner(
                        input=datapoint.input,
                        metadata=datapoint.metadata
                    )

                    evaluation = evaluator(
                        input=datapoint.input,
                        expected_output=datapoint.expected_output,
                        actual_output=output,
                        metadata=datapoint.metadata,
                    )

                    ctx_datapoint_run_id.set("")

                    payload = UpdateDatapointRunInput(
                        datapoint_run_id=datapoint_run.id,
                        output=output,
                        evaluation=evaluation,
                    )
                    self._montelo_client.update_datapoint_run(update_datapoint_run_input=payload)

                def process_in_batches(dps):
                    threads = []
                    for datapoint in dps:
                        thread = threading.Thread(target=process_datapoint, args=(datapoint,))
                        threads.append(thread)
                        thread.start()

                    # Wait for all threads in this batch to complete
                    for thread in threads:
                        thread.join()

                def chunked_datapoints(dps, size):
                    for i in range(0, len(dps), size):
                        yield dps[i:i + size]

                for batch in chunked_datapoints(filtered_datapoints, parallelism):
                    process_in_batches(batch)

                # Update skip for the next batch
                skip += take
                has_more_datapoints = skip < total_datapoints

            print("Experiment completed successfully!")
        except Exception as e:
            print(f"Error running experiment: {str(e)}")

    def create_and_run(
            self,
            *,
            dataset: StrictStr,
            name: StrictStr,
            description: Optional[StrictStr] = None,
            runner: Callable,
            evaluator: Callable,
            options: Optional[Dict] = None,
    ):
        experiment = self.create(
            dataset=dataset,
            name=name,
            description=description,
        )

        self.run(
            experiment_id=experiment.id,
            runner=runner,
            evaluator=evaluator,
            options=options,
        )



# flake8: noqa

# import apis into api package
from montelo.client.api.datapoint_api import DatapointApi
from montelo.client.api.datapoint_run_api import DatapointRunApi
from montelo.client.api.dataset_api import DatasetApi
from montelo.client.api.experiment_api import ExperimentApi
from montelo.client.api.health_api import HealthApi
from montelo.client.api.logs_api import LogsApi




from enum import Enum
from typing import Union, Dict, Optional, Literal

from pydantic import BaseModel, Field


class SchemaPrimitiveType(str, Enum):
    string = "string"
    number = "number"
    boolean = "boolean"


# Forward declare SchemaDataType because it references SchemaObject and SchemaArray
SchemaDataType = Union['SchemaPrimitiveType', 'SchemaObject', 'SchemaArray']


class SchemaObject(BaseModel):
    type: Literal["object"] = Field(default="object")
    properties: Dict[str, SchemaDataType]


class SchemaArray(BaseModel):
    type: Literal["array"] = Field(default="array")
    items: SchemaDataType


class CreateDatasetInput(BaseModel):
    """
    The name of the dataset.
    """
    name: str
    """
    The description of the dataset.
    """
    description: Optional[str] = None
    """
    The input schema of the dataset.
    """
    inputSchema: Dict[str, SchemaDataType]
    """
    The output schema of the dataset.
    """
    outputSchema: Dict[str, SchemaDataType]


class CreateFineTuneDatasetInput(BaseModel):
    """
    The name of the dataset.
    """
    name: str
    """
    The description of the dataset.
    """
    description: Optional[str] = None



from typing import Optional, Dict, Any

from montelo.MonteloClient import MonteloClient
from montelo.client import CreateDatasetInput, DatasetDto


class MonteloDatasets:
    def __init__(self, montelo_client: MonteloClient):
        self._montelo_client = montelo_client

    def create(
            self,
            *,
            name: str,
            description: Optional[str] = None,
            input_schema: Optional[Dict[str, Any]],
            output_schema: Optional[Dict[str, Any]],
    ) -> DatasetDto:
        params = CreateDatasetInput(
            name=name,
            description=description,
            input_schema=input_schema,
            output_schema=output_schema,
            is_fine_tuning=False,
        )
        return self._montelo_client.create_dataset(create_dataset_input=params)

    def create_fine_tune(
            self,
            *,
            name: str,
            description: Optional[str] = None,
    ) -> DatasetDto:
        params = CreateDatasetInput(
            name=name,
            description=description,
            is_fine_tuning=True,
        )
        return self._montelo_client.create_dataset(create_dataset_input=params)



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from montelo.client.models.token_info import TokenInfo
from typing import Optional, Set
from typing_extensions import Self

class LogInput(BaseModel):
    """
    LogInput
    """ # noqa: E501
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    source: StrictStr
    model: Optional[StrictStr] = None
    input: Optional[Dict[str, Any]] = None
    output: Optional[Dict[str, Any]] = None
    start_time: Optional[StrictStr] = Field(default=None, alias="startTime")
    end_time: Optional[StrictStr] = Field(default=None, alias="endTime")
    duration: Optional[Union[StrictFloat, StrictInt]] = None
    tokens: Optional[TokenInfo] = None
    extra: Optional[Dict[str, Any]] = None
    __properties: ClassVar[List[str]] = ["id", "name", "source", "model", "input", "output", "startTime", "endTime", "duration", "tokens", "extra"]

    @field_validator('source')
    def source_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['MANUAL', 'OPENAI', 'ANTHROPIC', 'MISTRAL', 'COHERE']):
            raise ValueError("must be one of enum values ('MANUAL', 'OPENAI', 'ANTHROPIC', 'MISTRAL', 'COHERE')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LogInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of tokens
        if self.tokens:
            _dict['tokens'] = self.tokens.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LogInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "source": obj.get("source"),
            "model": obj.get("model"),
            "input": obj.get("input"),
            "output": obj.get("output"),
            "startTime": obj.get("startTime"),
            "endTime": obj.get("endTime"),
            "duration": obj.get("duration"),
            "tokens": TokenInfo.from_dict(obj["tokens"]) if obj.get("tokens") is not None else None,
            "extra": obj.get("extra")
        })
        return _obj





# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.full_dataset_dto import FullDatasetDto

class TestFullDatasetDto(unittest.TestCase):
    """FullDatasetDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FullDatasetDto:
        """Test FullDatasetDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FullDatasetDto`
        """
        model = FullDatasetDto()
        if include_optional:
            return FullDatasetDto(
                id = '',
                env_id = '',
                slug = '',
                name = '',
                description = '',
                input_schema = None,
                output_schema = None,
                is_fine_tuning = True,
                datapoints = [
                    montelo.client.models.datapoint_dto.DatapointDto(
                        id = '', 
                        input = montelo.client.models.input.input(), 
                        expected_output = montelo.client.models.expected_output.expectedOutput(), 
                        source = 'TRACE', 
                        source_id = '', 
                        dataset_id = '', 
                        split = 'TRAIN', 
                        created_at = '', 
                        metadata = montelo.client.models.metadata.metadata(), )
                    ]
            )
        else:
            return FullDatasetDto(
                id = '',
                env_id = '',
                slug = '',
                name = '',
                input_schema = None,
                output_schema = None,
                is_fine_tuning = True,
                datapoints = [
                    montelo.client.models.datapoint_dto.DatapointDto(
                        id = '', 
                        input = montelo.client.models.input.input(), 
                        expected_output = montelo.client.models.expected_output.expectedOutput(), 
                        source = 'TRACE', 
                        source_id = '', 
                        dataset_id = '', 
                        split = 'TRAIN', 
                        created_at = '', 
                        metadata = montelo.client.models.metadata.metadata(), )
                    ],
        )
        """

    def testFullDatasetDto(self):
        """Test FullDatasetDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.create_dataset_input import CreateDatasetInput

class TestCreateDatasetInput(unittest.TestCase):
    """CreateDatasetInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateDatasetInput:
        """Test CreateDatasetInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateDatasetInput`
        """
        model = CreateDatasetInput()
        if include_optional:
            return CreateDatasetInput(
                name = '',
                description = '',
                input_schema = None,
                output_schema = None,
                is_fine_tuning = True
            )
        else:
            return CreateDatasetInput(
                name = '',
        )
        """

    def testCreateDatasetInput(self):
        """Test CreateDatasetInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



from typing import Optional, Dict, Any, Union

import httpx
from httpx import Timeout
from pydantic import BaseModel, Field, HttpUrl


class OpenAIClientConfig(BaseModel):
    api_key: Optional[str] = None
    organization: Optional[str] = None
    project: Optional[str] = None
    base_url: Union[str, HttpUrl, None] = None
    timeout: Union[
        float, Timeout, None] = None
    max_retries: int
    default_headers: Optional[Dict[str, str]] = None
    default_query: Optional[Dict[str, Any]] = None
    http_client: Optional[httpx.Client] = None
    _strict_response_validation: bool = False

    model_config = {
        "arbitrary_types_allowed": True
    }


class MonteloClientOptions(BaseModel):
    api_key: Optional[str] = Field(None)
    base_url: Optional[str] = Field(None)


class TraceParams(BaseModel):
    name: str
    user_id: Optional[str] = Field(None)
    extra: Optional[Dict[str, Any]] = None



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.create_log_input import CreateLogInput

class TestCreateLogInput(unittest.TestCase):
    """CreateLogInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateLogInput:
        """Test CreateLogInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateLogInput`
        """
        model = CreateLogInput()
        if include_optional:
            return CreateLogInput(
                datapoint_run_id = '',
                log = montelo.client.models.log_input.LogInput(
                    id = 'clsj9nupk000108jp9pxdcx5c', 
                    name = 'Agent X', 
                    source = 'MANUAL', 
                    model = 'gpt-4', 
                    input = What is your name?, 
                    output = I am an AI. I do not have a name., 
                    start_time = '2024-02-12T03:55:29.161Z', 
                    end_time = '2024-02-12T03:56:29.161Z', 
                    duration = 1.32, 
                    tokens = montelo.client.models.token_info.TokenInfo(
                        input_tokens = 5, 
                        output_tokens = 5, 
                        total_tokens = 10, ), 
                    extra = montelo.client.models.extra.extra(), ),
                trace = montelo.client.models.trace_input.TraceInput(
                    id = 'clsj9nupk000108jp9pxdcx5c', 
                    name = 'Top-level Trace', 
                    user_id = '', 
                    extra = montelo.client.models.extra.extra(), )
            )
        else:
            return CreateLogInput(
                log = montelo.client.models.log_input.LogInput(
                    id = 'clsj9nupk000108jp9pxdcx5c', 
                    name = 'Agent X', 
                    source = 'MANUAL', 
                    model = 'gpt-4', 
                    input = What is your name?, 
                    output = I am an AI. I do not have a name., 
                    start_time = '2024-02-12T03:55:29.161Z', 
                    end_time = '2024-02-12T03:56:29.161Z', 
                    duration = 1.32, 
                    tokens = montelo.client.models.token_info.TokenInfo(
                        input_tokens = 5, 
                        output_tokens = 5, 
                        total_tokens = 10, ), 
                    extra = montelo.client.models.extra.extra(), ),
        )
        """

    def testCreateLogInput(self):
        """Test CreateLogInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.full_dataset_with_count_dto import FullDatasetWithCountDto

class TestFullDatasetWithCountDto(unittest.TestCase):
    """FullDatasetWithCountDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FullDatasetWithCountDto:
        """Test FullDatasetWithCountDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FullDatasetWithCountDto`
        """
        model = FullDatasetWithCountDto()
        if include_optional:
            return FullDatasetWithCountDto(
                dataset = montelo.client.models.full_dataset_dto.FullDatasetDto(
                    id = '', 
                    env_id = '', 
                    slug = '', 
                    name = '', 
                    description = '', 
                    input_schema = montelo.client.models.input_schema.inputSchema(), 
                    output_schema = montelo.client.models.output_schema.outputSchema(), 
                    is_fine_tuning = True, 
                    datapoints = [
                        montelo.client.models.datapoint_dto.DatapointDto(
                            id = '', 
                            input = montelo.client.models.input.input(), 
                            expected_output = montelo.client.models.expected_output.expectedOutput(), 
                            source = 'TRACE', 
                            source_id = '', 
                            dataset_id = '', 
                            split = 'TRAIN', 
                            created_at = '', 
                            metadata = montelo.client.models.metadata.metadata(), )
                        ], ),
                total_count = 1.337
            )
        else:
            return FullDatasetWithCountDto(
                dataset = montelo.client.models.full_dataset_dto.FullDatasetDto(
                    id = '', 
                    env_id = '', 
                    slug = '', 
                    name = '', 
                    description = '', 
                    input_schema = montelo.client.models.input_schema.inputSchema(), 
                    output_schema = montelo.client.models.output_schema.outputSchema(), 
                    is_fine_tuning = True, 
                    datapoints = [
                        montelo.client.models.datapoint_dto.DatapointDto(
                            id = '', 
                            input = montelo.client.models.input.input(), 
                            expected_output = montelo.client.models.expected_output.expectedOutput(), 
                            source = 'TRACE', 
                            source_id = '', 
                            dataset_id = '', 
                            split = 'TRAIN', 
                            created_at = '', 
                            metadata = montelo.client.models.metadata.metadata(), )
                        ], ),
                total_count = 1.337,
        )
        """

    def testFullDatasetWithCountDto(self):
        """Test FullDatasetWithCountDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.api.logs_api import LogsApi


class TestLogsApi(unittest.TestCase):
    """LogsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LogsApi()

    def tearDown(self) -> None:
        pass

    def test_logs_controller_create_log(self) -> None:
        """Test case for logs_controller_create_log

        """
        pass

    def test_logs_controller_end_log(self) -> None:
        """Test case for logs_controller_end_log

        """
        pass


if __name__ == '__main__':
    unittest.main()



from typing import Any, Dict, Literal, Optional, List

from montelo.MonteloClient import MonteloClient
from montelo.client import AddToDatasetInput, DatapointDto


class MonteloDatapoints:
    def __init__(self, montelo_client: MonteloClient):
        self._montelo_client = montelo_client

    def create(
            self,
            *,
            dataset: str,
            input: Dict[str, Any],
            expected_output: Dict[str, Any],
            split: Optional[Literal["TRAIN", "TEST"]] = None,
            metadata: Optional[Dict[str, Any]] = None,
    ) -> DatapointDto:
        payload = AddToDatasetInput(
            input=input,
            expected_output=expected_output,
            split=split,
            metadata=metadata,
            source="API",
            source_id=None,
        )
        return self._montelo_client.create_datapoint(
            dataset_slug=dataset,
            add_to_dataset_input=payload
        )

    def create_many(
            self,
            *,
            dataset: str,
            datapoints: List[Dict[str, Any]],
            split: Optional[Literal["TRAIN", "TEST"]] = None,
    ) -> None:
        def chunk_list(data, size):
            return (data[i:i + size] for i in range(0, len(data), size))

        chunks = chunk_list(datapoints, 100)

        def process_chunk(chunk):
            dps = [
                AddToDatasetInput(
                    input=datapoint["input"],
                    expected_output=datapoint["expected_output"],
                    metadata=datapoint.get("metadata", None),
                    split=split,
                    source="API",
                    source_id=None
                ) for datapoint in chunk
            ]
            self._montelo_client.create_batch_datapoints(slug=dataset, datapoints=dps)

        [process_chunk(chunk) for chunk in chunks]



from datetime import datetime
from typing import Optional, Dict

from pydantic import StrictStr

from montelo.Log import Log
from montelo.MonteloClient import MonteloClient
from montelo.client import LogInput, TokenInfo
from montelo.utils import cuid_generator, get_current_utc_time


class Span:
    def __init__(
            self,
            *,
            id: StrictStr,
            name: StrictStr,
            montelo_client: MonteloClient
    ):
        self._id = id
        self._name = name
        self._montelo_client = montelo_client

    def span(
            self,
            *,
            name: StrictStr,
            input: Optional[Dict] = None,
            output: Optional[Dict] = None,
            start_time: Optional[StrictStr] = None,
            end_time: Optional[StrictStr] = None,
            extra: Optional[Dict] = None,
    ):
        id = cuid_generator()
        now = get_current_utc_time()
        start_time = start_time or now
        end_time = end_time or now
        name = self._name + " / " + name

        self._montelo_client.create_log(
            log=LogInput(
                id=id,
                name=name,
                input=input,
                output=output,
                start_time=start_time,
                end_time=end_time,
                extra=extra,
                source="MANUAL"
            ),
        )

        return Span(
            id=id,
            name=name,
            montelo_client=self._montelo_client
        )

    def log(
            self,
            name: StrictStr,
            model: Optional[StrictStr] = None,
            input: Optional[Dict] = None,
            output: Optional[Dict] = None,
            start_time: Optional[StrictStr] = None,
            end_time: Optional[StrictStr] = None,
            duration: Optional[int] = None,
            token_info: Optional[TokenInfo] = None,
            extra: Optional[Dict] = None,
    ):
        id = cuid_generator()
        now = get_current_utc_time()
        start_time = start_time or now
        end_time = end_time or now
        name = self._name + " / " + name

        self._montelo_client.create_log(
            log=LogInput(
                id=id,
                model=model,
                name=name,
                input=input,
                output=output,
                start_time=start_time,
                end_time=end_time,
                extra=extra,
                source="MANUAL",
                duration=duration,
                token_info=token_info,
            ),
        )

        return Log(id=id, montelo_client=self._montelo_client)



from datetime import datetime
from functools import reduce
from typing import TypedDict, Optional, Dict, List

import openai.types.chat
from openai import OpenAI, DEFAULT_MAX_RETRIES, NOT_GIVEN
from openai.resources import Chat
from openai.resources.chat import Completions
from openai.types.chat import ChatCompletionChunk

from montelo.MonteloClient import MonteloClient
from montelo.client import LogInput
from montelo.types import OpenAIClientConfig
from montelo.utils import format_utc_date


class TimeInterval(TypedDict):
    start_time: str
    end_time: str
    duration: float


class MonteloLogExtend(TypedDict):
    name: Optional[str]
    extra: Optional[Dict]


def process_final_message(chunks):
    def reducer(acc, chunk_with_index):
        index, chunk = chunk_with_index

        if isinstance(chunk, ChatCompletionChunk):
            delta = chunk.choices[0].delta if chunk.choices else {}
            tool_calls = delta.tool_calls if delta else []
            function_call = delta.function_call if delta else None

            if tool_calls:
                if index == 0:
                    acc["tool_calls"] = [{
                        "id": tool.id,
                        "type": tool.type,
                        "function": {
                            "name": tool.function.name,
                            "arguments": tool.function.arguments
                        }
                    } for tool in tool_calls]
                else:
                    for i, tool in enumerate(acc.get("tool_calls", [])):
                        matching_tool_call = next((tc for tc in tool_calls if tc.index == i), None)
                        if matching_tool_call:
                            acc["tool_calls"][i]["function"]["arguments"] += matching_tool_call.function.arguments
            elif function_call:
                if index == 0:
                    acc["function_call"] = {
                        "name": function_call.name,
                        "arguments": function_call.arguments
                    }
                else:
                    acc["function_call"]["arguments"] += function_call.arguments
            elif delta and delta.content:
                if index == 0:
                    acc["content"] = delta.content
                else:
                    acc["content"] = (acc.get("content") or "") + delta.content
        else:
            print(f"Unexpected data type for chunk at index {index}: {type(chunk)}")

        return acc

    initial_value = {"role": "assistant"}
    final_message = reduce(reducer, enumerate(chunks), initial_value)
    return final_message


class ExtendedChatCompletions(Completions):
    def __init__(self, *, client, montelo_client: MonteloClient):
        super().__init__(client)
        self._montelo_client = montelo_client

    def create(self, *args, **kwargs):
        start_time = datetime.now()
        start_time_iso = format_utc_date(start_time)
        name = kwargs.pop("name", None)
        extra = kwargs.pop("extra", None)

        res = super().create(*args, **kwargs)

        stream = kwargs.get("stream", False)
        if stream:
            chunks: List[ChatCompletionChunk] = []
            for chunk in res:
                chunks.append(chunk)
                yield chunk

            end_time = datetime.now()
            end_time_iso = format_utc_date(end_time)

            duration = (end_time - start_time).total_seconds()

            data = openai.types.chat.ChatCompletion(
                id=chunks[0].id,
                model=chunks[0].model,
                object="chat.completion",
                created=chunks[0].created,
                system_fingerprint=chunks[0].system_fingerprint,
                usage=None,  # will be calculated on backend
                choices=[
                    {
                        "index": chunks[0].choices[0].index,
                        "logprobs": chunks[0].choices[0].logprobs or None,
                        "finish_reason": chunks[0].choices[0].finish_reason or "stop",
                        "message": process_final_message(chunks),
                    }
                ]
            )

            self._log_to_db(
                base=kwargs,
                extend={
                    "name": name,
                    "extra": extra
                },
                output=data,
                time={
                    "start_time": start_time_iso,
                    "end_time": end_time_iso,
                    "duration": duration
                }
            )
        else:
            end_time = datetime.now()
            end_time_iso = format_utc_date(end_time)

            duration = (end_time - start_time).total_seconds()

            self._log_to_db(
                base=kwargs,
                extend={
                    "name": name,
                    "extra": extra
                },
                output=res,
                time={
                    "start_time": start_time_iso,
                    "end_time": end_time_iso,
                    "duration": duration
                },
            )

        return res

    def _log_to_db(
            self,
            *,
            base,
            extend: MonteloLogExtend,
            output: openai.types.chat.ChatCompletion,
            time: TimeInterval,
    ):
        payload = LogInput(
            **time,
            **extend,
            source="OPENAI",
            model=output.model,
            input=base,
            output=output.dict()
        )

        self._montelo_client.create_log(log=payload)


class ExtendedChat(Chat):
    def __init__(self, *, client, montelo_client: MonteloClient):
        super().__init__(client)
        self.completions = ExtendedChatCompletions(client=client, montelo_client=montelo_client)


class ExtendedOpenAI(OpenAI):
    def __init__(self, *, montelo_client: MonteloClient, config: Optional[OpenAIClientConfig] = None):
        config = config if config else {}
        super().__init__(
            api_key=config.get("api_key"),
            organization=config.get("organization"),
            project=config.get("project"),
            base_url=config.get("base_url"),
            timeout=config.get("timeout", NOT_GIVEN),
            max_retries=config.get("max_retries", DEFAULT_MAX_RETRIES),
            default_headers=config.get("default_headers"),
            default_query=config.get("default_query"),
            http_client=config.get("http_client"),
            _strict_response_validation=config.get("_strict_response_validation", False)
        )
        self.chat = ExtendedChat(client=self, montelo_client=montelo_client)



from pydantic import StrictStr

from montelo.MonteloClient import MonteloClient
from montelo.client import EndLogInput


class Log:
    def __init__(self, *, id: StrictStr, montelo_client: MonteloClient):
        self._id = id
        self._montelo_client = montelo_client

    def end(
            self,
            *,
            id: StrictStr,
            log: EndLogInput
    ):
        self._montelo_client.end_log(id=id, log=log)



from .MonteloDatapoints import MonteloDatapoints
from .MonteloDatasets import MonteloDatasets
from .MonteloExperiments import MonteloExperiments

__all__ = [
    "MonteloDatapoints",
    "MonteloDatasets",
    "MonteloExperiments",
]



from datetime import datetime
from typing import Optional, Dict

from pydantic import StrictStr

from montelo.Log import Log
from montelo.MonteloClient import MonteloClient
from montelo.Span import Span
from montelo.client import LogInput, TokenInfo
from montelo.core.MonteloDatapoints import MonteloDatapoints
from montelo.core.MonteloDatasets import MonteloDatasets
from montelo.core.MonteloExperiments import MonteloExperiments
from montelo.extended.ExtendedOpenAI import ExtendedOpenAI
from montelo.types import MonteloClientOptions, OpenAIClientConfig
from montelo.utils import cuid_generator, get_current_utc_time


class Montelo:
    def __init__(
            self,
            *,
            montelo: Optional[MonteloClientOptions] = None,
            openai_config: Optional[OpenAIClientConfig] = None,
    ):
        self._constructor_options = montelo
        self._montelo_client = MonteloClient(options=montelo)
        self.openai = ExtendedOpenAI(montelo_client=self._montelo_client, config=openai_config)
        self.datasets = MonteloDatasets(montelo_client=self._montelo_client)
        self.datapoints = MonteloDatapoints(montelo_client=self._montelo_client)
        self.experiments = MonteloExperiments(montelo_client=self._montelo_client)

    def span(
            self,
            *,
            name: StrictStr,
            input: Optional[Dict] = None,
            output: Optional[Dict] = None,
            start_time: Optional[StrictStr] = None,
            end_time: Optional[StrictStr] = None,
            extra: Optional[Dict] = None,
    ):
        id = cuid_generator()
        now = get_current_utc_time()
        start_time = start_time or now
        end_time = end_time or now

        self._montelo_client.create_log(
            log=LogInput(
                id=id,
                name=name,
                input=input,
                output=output,
                start_time=start_time,
                end_time=end_time,
                extra=extra,
                source="MANUAL"
            ),
        )

        return Span(
            id=id,
            name=name,
            montelo_client=self._montelo_client
        )

    def log(
            self,
            name: StrictStr,
            model: Optional[StrictStr] = None,
            input: Optional[Dict] = None,
            output: Optional[Dict] = None,
            start_time: Optional[StrictStr] = None,
            end_time: Optional[StrictStr] = None,
            duration: Optional[int] = None,
            token_info: Optional[TokenInfo] = None,
            extra: Optional[Dict] = None,
    ):
        id = cuid_generator()
        now = get_current_utc_time()
        start_time = start_time or now
        end_time = end_time or now

        self._montelo_client.create_log(
            log=LogInput(
                id=id,
                model=model,
                name=name,
                input=input,
                output=output,
                start_time=start_time,
                end_time=end_time,
                extra=extra,
                source="MANUAL",
                duration=duration,
                token_info=token_info,
            ),
        )

        return Log(id=id, montelo_client=self._montelo_client)

    def trace(
            self,
            *,
            name: StrictStr,
            user_id: Optional[StrictStr] = None,
            extra: Optional[Dict] = None,
    ):
        trace = self._montelo_client.get_trace()
        if trace:
            raise Exception("Trace already set on this Montelo instance.")

        new_montelo_instance = Montelo(montelo=self._constructor_options)
        new_montelo_instance._montelo_client.set_trace(
            trace={
                "id": cuid_generator(),
                "name": name,
                "user_id": user_id,
                "extra": extra,
            }
        )
        return new_montelo_instance



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.log_input import LogInput

class TestLogInput(unittest.TestCase):
    """LogInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogInput:
        """Test LogInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogInput`
        """
        model = LogInput()
        if include_optional:
            return LogInput(
                id = 'clsj9nupk000108jp9pxdcx5c',
                name = 'Agent X',
                source = 'MANUAL',
                model = 'gpt-4',
                input = What is your name?,
                output = I am an AI. I do not have a name.,
                start_time = '2024-02-12T03:55:29.161Z',
                end_time = '2024-02-12T03:56:29.161Z',
                duration = 1.32,
                tokens = montelo.client.models.token_info.TokenInfo(
                    input_tokens = 5, 
                    output_tokens = 5, 
                    total_tokens = 10, ),
                extra = None
            )
        else:
            return LogInput(
                source = 'MANUAL',
        )
        """

    def testLogInput(self):
        """Test LogInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from montelo.client.models.add_to_dataset_input import AddToDatasetInput
from montelo.client.models.batch_add_to_dataset_input import BatchAddToDatasetInput
from montelo.client.models.create_datapoint_run_input import CreateDatapointRunInput
from montelo.client.models.create_dataset_input import CreateDatasetInput
from montelo.client.models.create_experiment_input import CreateExperimentInput
from montelo.client.models.create_log_input import CreateLogInput
from montelo.client.models.datapoint_dto import DatapointDto
from montelo.client.models.datapoint_run_dto import DatapointRunDto
from montelo.client.models.dataset_dto import DatasetDto
from montelo.client.models.delete_success_dto import DeleteSuccessDto
from montelo.client.models.end_log_input import EndLogInput
from montelo.client.models.event_queued_dto import EventQueuedDto
from montelo.client.models.experiment_dto import ExperimentDto
from montelo.client.models.experiment_with_datapoints_dto import ExperimentWithDatapointsDto
from montelo.client.models.full_dataset_dto import FullDatasetDto
from montelo.client.models.full_dataset_with_count_dto import FullDatasetWithCountDto
from montelo.client.models.health_controller_check200_response import HealthControllerCheck200Response
from montelo.client.models.health_controller_check200_response_info_value import HealthControllerCheck200ResponseInfoValue
from montelo.client.models.health_controller_check503_response import HealthControllerCheck503Response
from montelo.client.models.log_input import LogInput
from montelo.client.models.paginated_experiment_with_datapoints_dto import PaginatedExperimentWithDatapointsDto
from montelo.client.models.token_info import TokenInfo
from montelo.client.models.trace_input import TraceInput
from montelo.client.models.update_datapoint_run_input import UpdateDatapointRunInput



# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.datapoint_run_dto import DatapointRunDto

class TestDatapointRunDto(unittest.TestCase):
    """DatapointRunDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DatapointRunDto:
        """Test DatapointRunDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DatapointRunDto`
        """
        model = DatapointRunDto()
        if include_optional:
            return DatapointRunDto(
                id = '',
                experiment_id = '',
                datapoint_id = '',
                output = None
            )
        else:
            return DatapointRunDto(
                id = '',
                experiment_id = '',
                datapoint_id = '',
                output = None,
        )
        """

    def testDatapointRunDto(self):
        """Test DatapointRunDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
